@@ -5,7 +5,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Time::Piece;
 use CLDR::Number;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 sub register {
     my ($self, $app, $config) = @_;
@@ -102,24 +102,27 @@ sub _date_long {
 
     return "%Y.%m.%d %H:%M:%S" if !$lang;
 
+    $lang = lc $lang;
+    $lang =~ s/-/_/g;
+
     state $formats = {
-        ar_SA   => '%d.%m.%Y %H:%M:%S',
+        ar_sa   => '%d.%m.%Y %H:%M:%S',
         bg      => '%d.%m.%Y %H:%M:%S',
         ca      => '%d.%m.%Y %H:%M:%S',
         cs      => '%d/%m/%Y %H:%M:%S',
         da      => '%d.%m.%Y %H:%M:%S',
         de      => '%d.%m.%Y %H:%M:%S',
         el      => '%d.%m.%Y %H:%M:%S',
-        en_CA   => '%Y-%m-%d %H:%M:%S',
-        en_GB   => '%d/%m/%Y %H:%M:%S',
+        en_ca   => '%Y-%m-%d %H:%M:%S',
+        en_gb   => '%d/%m/%Y %H:%M:%S',
         en      => '%m/%d/%Y %H:%M:%S',
-        es_CO   => '%d/%m/%Y - %H:%M:%S',
-        es_MX   => '%d/%m/%Y - %H:%M:%S',
+        es_co   => '%d/%m/%Y - %H:%M:%S',
+        es_mx   => '%d/%m/%Y - %H:%M:%S',
         es      => '%d/%m/%Y - %H:%M:%S',
         et      => '%d.%m.%Y %H:%M:%S',
         fa      => '%d.%m.%Y %H:%M:%S',
         fi      => '%d.%m.%Y %H:%M:%S',
-        fr_CA   => '%d.%m.%Y %H:%M:%S',
+        fr_ca   => '%d.%m.%Y %H:%M:%S',
         fr      => '%d.%m.%Y %H:%M:%S',
         he      => '%d/%m/%Y %H:%M:%S',
         hi      => '%d/%m/%Y - %H:%M:%S',
@@ -130,23 +133,23 @@ sub _date_long {
         lt      => '%Y-%m-%d %H:%M:%S',
         lv      => '%d.%m.%Y %H:%M:%S',
         ms      => '%d.%m.%Y %H:%M:%S',
-        nb_NO   => '%d/%m %Y %H:%M:%S',
+        nb_no   => '%d/%m %Y %H:%M:%S',
         nl      => '%d-%m-%Y %H:%M:%S',
         pl      => '%Y-%m-%d %H:%M:%S',
-        pt_BR   => '%d/%m/%Y %H:%M:%S',
+        pt_br   => '%d/%m/%Y %H:%M:%S',
         pt      => '%Y-%m-%d %H:%M:%S',
         ru      => '%d.%m.%Y %H:%M:%S',
-        sk_SK   => '%d.%m.%Y %H:%M:%S',
+        sk_sk   => '%d.%m.%Y %H:%M:%S',
         sl      => '%d.%m.%Y %H:%M:%S',
-        sr_Cyrl => '%d.%m.%Y %H:%M:%S',
-        sr_Latn => '%d.%m.%Y %H:%M:%S',
+        sr_cyrl => '%d.%m.%Y %H:%M:%S',
+        sr_latn => '%d.%m.%Y %H:%M:%S',
         sv      => '%d/%m %Y %H:%M:%S',
         sw      => '%m/%d/%Y %H:%M:%S',
         tr      => '%d.%m.%Y %H:%M:%S',
         uk      => '%m/%d/%Y %H:%M:%S',
-        vi_VN   => '%d.%m.%Y %H:%M:%S',
-        zh_CN   => '%Y.%m.%d %H:%M:%S',
-        zh_TW   => '%Y.%m.%d %H:%M:%S',
+        vi_vn   => '%d.%m.%Y %H:%M:%S',
+        zh_cn   => '%Y.%m.%d %H:%M:%S',
+        zh_tw   => '%Y.%m.%d %H:%M:%S',
     };
 
     return $formats->{$lang} // '%Y.%m.%d %H:%M:%S';
@@ -157,24 +160,27 @@ sub _date_short {
 
     return "%Y.%m.%d" if !$lang;
 
+    $lang = lc $lang;
+    $lang =~ s/-/_/g;
+
     state $formats = {
-        ar_SA   => '%d.%m.%Y',
+        ar_sa   => '%d.%m.%Y',
         bg      => '%d.%m.%Y',
         ca      => '%d.%m.%Y',
         cs      => '%d/%m/%Y',
         da      => '%d.%m.%Y',
         de      => '%d.%m.%Y',
         el      => '%d.%m.%Y',
-        en_CA   => '%Y-%m-%d',
-        en_GB   => '%d/%m/%Y',
+        en_ca   => '%Y-%m-%d',
+        en_gb   => '%d/%m/%Y',
         en      => '%m/%d/%Y',
-        es_CO   => '%d/%m/%Y',
-        es_MX   => '%d/%m/%Y',
+        es_co   => '%d/%m/%Y',
+        es_mx   => '%d/%m/%Y',
         es      => '%d/%m/%Y',
         et      => '%d.%m.%Y',
         fa      => '%d.%m.%Y',
         fi      => '%d.%m.%Y',
-        fr_CA   => '%d.%m.%Y',
+        fr_ca   => '%d.%m.%Y',
         fr      => '%d.%m.%Y',
         he      => '%d/%m/%Y',
         hi      => '%d/%m/%Y',
@@ -185,23 +191,23 @@ sub _date_short {
         lt      => '%Y-%m-%d',
         lv      => '%d.%m.%Y',
         ms      => '%d.%m.%Y',
-        nb_NO   => '%d.%m.%Y',
+        nb_no   => '%d.%m.%Y',
         nl      => '%d-%m-%Y',
         pl      => '%Y-%m-%d',
-        pt_BR   => '%d/%m/%Y',
+        pt_br   => '%d/%m/%Y',
         pt      => '%Y-%m-%d',
         ru      => '%d.%m.%Y',
-        sk_SK   => '%d.%m.%Y',
+        sk_sk   => '%d.%m.%Y',
         sl      => '%d.%m.%Y',
-        sr_Cyrl => '%d.%m.%Y',
-        sr_Latn => '%d.%m.%Y',
+        sr_cyrl => '%d.%m.%Y',
+        sr_latn => '%d.%m.%Y',
         sv      => '%Y.%m.%d',
         sw      => '%m/%d/%Y',
         tr      => '%d.%m.%Y',
         uk      => '%m/%d/%Y',
-        vi_VN   => '%d.%m.%Y',
-        zh_CN   => '%Y.%m.%d',
-        zh_TW   => '%Y.%m.%d',
+        vi_vn   => '%d.%m.%Y',
+        zh_cn   => '%Y.%m.%d',
+        zh_tw   => '%Y.%m.%d',
     };
 
     return $formats->{$lang} // '%Y.%m.%d';
@@ -221,7 +227,7 @@ Mojolicious::Plugin::I18NUtils - provide some helper functions for I18N
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
